@@ -14,7 +14,8 @@ pub fn name(message: &Message) -> String {
 /// Returns name of the is-a-variant function for the given `message`
 pub fn sig(message: &Message, options: &Options) -> String {
     format!(
-        "bool {variant_predicate_name}(const {diagnostic_message_blob} *self_blob)",
+        "bool {fn_attributes} {variant_predicate_name}(const {diagnostic_message_blob} *self_blob)",
+        fn_attributes = options.fn_attributes,
         variant_predicate_name = name(message),
         diagnostic_message_blob = options.diagnostic_message_blob_name
     )
