@@ -28,7 +28,7 @@ fn test_generate() {
 
 fn message_stubs_h(options: &Options) -> String {
     lib_ruby_parser_nodes::messages()
-        .map(&|message| {
+        .map(|message| {
             format!(
                 "typedef struct {{}} {};",
                 options.message_variant_blob_name(message)
@@ -39,7 +39,7 @@ fn message_stubs_h(options: &Options) -> String {
 
 fn node_stubs_h(options: &Options) -> String {
     lib_ruby_parser_nodes::nodes()
-        .map(&|node| {
+        .map(|node| {
             format!(
                 "typedef struct {{}} {};",
                 options.node_variant_blob_name(node)
